==> huaweicloudsdkmrs-3.0.82-py2.py3-none-any.whl: huaweicloudsdkmrs/v1/model/delete_job_execution_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteJobExecutionRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'job_execution_id': 'str'
    }

    attribute_map = {
        'job_execution_id': 'job_execution_id'
    }

    def __init__(self, job_execution_id=None):
        """DeleteJobExecutionRequest - a model defined in huaweicloud sdk"""
        
        

        self._job_execution_id = None
        self.discriminator = None

        self.job_execution_id = job_execution_id

    @property
    def job_execution_id(self):
        """Gets the job_execution_id of this DeleteJobExecutionRequest.

        作业ID。

        :return: The job_execution_id of this DeleteJobExecutionRequest.
        :rtype: str
        """
        return self._job_execution_id

    @job_execution_id.setter
    def job_execution_id(self, job_execution_id):
        """Sets the job_execution_id of this DeleteJobExecutionRequest.

        作业ID。

        :param job_execution_id: The job_execution_id of this DeleteJobExecutionRequest.
        :type: str
        """
        self._job_execution_id = job_execution_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteJobExecutionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmrs-3.0.100-py2.py3-none-any.whl: huaweicloudsdkmrs/v1/model/delete_job_execution_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteJobExecutionRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'job_execution_id': 'str'
    }

    attribute_map = {
        'job_execution_id': 'job_execution_id'
    }

    def __init__(self, job_execution_id=None):
        """DeleteJobExecutionRequest

        The model defined in huaweicloud sdk

        :param job_execution_id: 作业ID。
        :type job_execution_id: str
        """
        
        

        self._job_execution_id = None
        self.discriminator = None

        self.job_execution_id = job_execution_id

    @property
    def job_execution_id(self):
        """Gets the job_execution_id of this DeleteJobExecutionRequest.

        作业ID。

        :return: The job_execution_id of this DeleteJobExecutionRequest.
        :rtype: str
        """
        return self._job_execution_id

    @job_execution_id.setter
    def job_execution_id(self, job_execution_id):
        """Sets the job_execution_id of this DeleteJobExecutionRequest.

        作业ID。

        :param job_execution_id: The job_execution_id of this DeleteJobExecutionRequest.
        :type job_execution_id: str
        """
        self._job_execution_id = job_execution_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteJobExecutionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
